[Apache-dispatch-devel] SF.net SVN: apache-dispatch:[83] trunk
Brought to you by:
geoffrey_young,
phred_moyer
|
From: <phr...@us...> - 2009-04-26 07:13:16
|
Revision: 83
http://apache-dispatch.svn.sourceforge.net/apache-dispatch/?rev=83&view=rev
Author: phred_moyer
Date: 2009-04-26 07:13:11 +0000 (Sun, 26 Apr 2009)
Log Message:
-----------
Fixup the Makefile.PL logic so that it tries mp2 first.
I think this mp1/mp2 logic stuff is finally working well.
Modified Paths:
--------------
trunk/Changes
trunk/Makefile.PL
trunk/lib/Apache/Dispatch/Util.pm
Modified: trunk/Changes
===================================================================
--- trunk/Changes 2009-04-25 23:24:32 UTC (rev 82)
+++ trunk/Changes 2009-04-26 07:13:11 UTC (rev 83)
@@ -1,6 +1,7 @@
Revision history for Perl extension Apache::Dispatch
0.13-dev
+ - fix some of the Makefile.PL logic so that mp2 is checked first
0.12 04.25.2009 16:06 PST
- set library versions to $Apache::Dispatch::Util::VERSION so PAUSE
Modified: trunk/Makefile.PL
===================================================================
--- trunk/lib/Apache/Dispatch/Util.pm 2009-04-25 23:24:32 UTC (rev 82)
+++ trunk/lib/Apache/Dispatch/Util.pm 2009-04-26 07:13:11 UTC (rev 83)
@@ -3,7 +3,7 @@
use strict;
use warnings;
-our $VERSION = 0.13-dev;
+our $VERSION = '0.13-dev';
=head1 NAME
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
|
--- trunk/Makefile.PL 2009-04-25 23:24:32 UTC (rev 82)
+++ trunk/Makefile.PL 2009-04-26 07:13:11 UTC (rev 83)
@@ -4,7 +4,7 @@
use warnings;
# minimum version of A::B required
-use Apache::Bootstrap 0.06;
+use Apache::Bootstrap 0.07;
my $bootstrap;
@@ -14,16 +14,19 @@
mod_perl => 1.30 });
}
-# allow builds with mod_perl one when MOD_PERL_1_BUILD ENV is set
-my $mp_gen;
-if ( $ENV{MOD_PERL_1_BUILD} ) {
+# try mp2 first, but allow builds with mod_perl one
+# when MOD_PERL_1_BUILD ENV is set (for maintainers mostly)
+my $mp_gen = $bootstrap->satisfy_mp_generation(2);
+if (! $ENV{MOD_PERL_1_BUILD} && $mp_gen) {
- $mp_gen = $bootstrap->satisfy_mp_generation(1);
+ warn("building for mp2 since MOD_PERL_1_BUILD not set");
+ push @ARGV, "-apxs $ENV{MP_APXS}" if exists $ENV{MP_APXS};
+
+} elsif ( $mp_gen = $bootstrap->satisfy_mp_generation(1)) {
+
+ warn("building for mp1");
} else {
-
- # else we build for mp2
- push @ARGV, "-apxs $ENV{MP_APXS}" if exists $ENV{MP_APXS};
- $mp_gen = $bootstrap->satisfy_mp_generation(2);
+ die "no mp generation could be satisfied\n";
}
# check for Apache::Test, $HAS_APACHE_TEST contains version or is undefined
Modified: trunk/lib/Apache/Dispatch/Util.pm
===================================================================